Examples — PyProcar 6.2.1 documentation

Skip to main content
`Ctrl`+`K`

# Examples

Here is a gallery of several examples demonstrating what PyProcar can do!

## Band Structure

These examples demonstrate the band structure plotting capabilities.

Autobands plotting

Autobands plotting

Plotting non colinear band structures in VASP

Plotting non colinear band structures in VASP

Plotting non colinear band structures in Quantum Espresso

Plotting non colinear band structures in Quantum Espresso

Plotting Atomic Levels

Plotting Atomic Levels

Plotting Inverse participation ratio

Plotting Inverse participation ratio

Comparing band structures

Comparing band structures

Unfolding Band Structure

Unfolding Band Structure

Plotting spin polarized band structures

Plotting spin polarized band structures

Plotting band structure

Plotting band structure

Plotting 2D band structure

Plotting 2D band structure

Plotting with Configurations in pyprocar

Plotting with Configurations in pyprocar

## Density of States

These examples demonstrate the density of states plotting capabilities.

Plotting non colinear dos in VASP

Plotting non colinear dos in VASP

Plotting non colinear dos in Quantum Espresso

Plotting non colinear dos in Quantum Espresso

Plotting density of states

Plotting density of states

Plotting spin-polarized density of states

Plotting spin-polarized density of states

Plotting with Configurations in pyprocar

Plotting with Configurations in pyprocar

## Bands and Dos plot

These examples demonstrate the bandsdosplot plotting capabilities.

Plotting bandsdosplot

Plotting bandsdosplot

Plotting bandsdosplot

Plotting bandsdosplot

## Fermi 2D

These examples demonstrate the Fermi2D plotting capabilities.

Plotting fermi2d noncolinear

Plotting fermi2d noncolinear

Plotting fermi2d

Plotting fermi2d

Plotting with Configurations in pyprocar

Plotting with Configurations in pyprocar

Plotting rashba spin splitting

Plotting rashba spin splitting

## Fermi 3D

These examples demonstrate the Fermi3D plotting capabilities.

Symmetry does not currently work! Make sure for fermi surface calculations turn off symmetry

Plotting fermi3d plain

Plotting fermi3d plain

Plotting fermi3d isoslider

Plotting fermi3d isoslider

Plotting fermi3d spin_texture

Plotting fermi3d spin_texture

Plotting fermi3d isovalue_gif

Plotting fermi3d isovalue_gif

Showing how to get van alphen fequencies from the fermi surface

Showing how to get van alphen fequencies from the fermi surface

Plotting fermi3d spin-polarized

Plotting fermi3d spin-polarized

Plotting with Configurations in pyprocar

Plotting with Configurations in pyprocar

Plotting fermi3d cross_section

Plotting fermi3d cross_section

## Other

These examples demonstrate other capabilities.

Example of finding the bandgap

Example of finding the bandgap

Example of kmesh_generator

Example of kmesh_generator

Example of kpath_generator

Example of kpath_generator

Example of finding the bandgap

Example of finding the bandgap

## PyPoscar

These examples demonstrate the PyPoscar module

Visualizing Clusters in Bi2Se3 Slab

Visualizing Clusters in Bi2Se3 Slab

Analyzing Radial Distribution Functions (RDF)

Analyzing Radial Distribution Functions (RDF)

Finding defects in a POSCAR file

Finding defects in a POSCAR file

Substituting Atoms in a POSCAR File

Substituting Atoms in a POSCAR File

Modifying a POSCAR File: Scaling, Supercells, and Defects

Modifying a POSCAR File: Scaling, Supercells, and Defects

Gallery generated by Sphinx-Gallery